#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%global origname olm
%global origlibname lib%{origname}
%global libname %{origlibname}3
%global descriptor An implementation of the Double Ratchet cryptographic ratchet \
in C and C++, including an implementation of the Megolm cryptographic ratchet
Name:           %{origname}
Version:        3.2.16
Release:        1.4
Summary:        Double Ratchet cryptographic library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://gitlab.matrix.org/matrix-org/olm/
Source0:        https://gitlab.matrix.org/matrix-org/olm/-/archive/%{version}/olm-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM cmake-enable-testing-builddir.patch -- Enable testing inside the build directory
Patch0:         cmake-enable-testing-builddir.patch
BuildRequires:  %{python_module cffi >= 1.0.0}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
Requires:       %{libname} = %{version}
Requires:       python-cffi >= 1.0.0
%ifpython2
Requires:       python-typing
%endif
%python_subpackages

%description
%{descriptor} .
This package contains %{python_flavor} bindings for %{origname}.

%package -n %{origname}-doc
Summary:        Documentation files for %{origname}
Group:          Documentation/Other
Suggests:       %{libname} = %{version}
BuildArch:      noarch

%description -n %{origname}-doc
%{descriptor}.
%{summary}

%package -n %{libname}
Summary:        Double Ratchet cryptographic library as a C API
Group:          System/Libraries
Recommends:     %{origname}-doc = %{version}

%description -n %{libname}
%{descriptor}.
%{summary}

%package -n %{origname}-devel
Summary:        Development files for %{origname}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description -n %{origname}-devel
%{descriptor}.
%{summary}

%prep
%autosetup -p1 -n %{origname}-%{version}

%build
%cmake
%cmake_build

cd ../python
%python_build

%check
%if 0%{?suse_version} < 1550
export LD_LIBRARY_PATH="%{buildroot}%{_libdir}"
%endif
%ctest

%install
%cmake_install
cd python
%python_install

%fdupes %{buildroot}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{origname}-doc
%defattr(0644, root, root, 0755)
%doc *.md *.rst docs/*.md docs/*.svg

%files -n %{libname}
%license LICENSE
%{_libdir}/%{origlibname}.so.*

%files -n %{origname}-devel
%defattr(0644, root, root, 0755)
%{_includedir}/%{origname}
%{_libdir}/%{origlibname}.so
%{_libdir}/cmake/Olm
%{_libdir}/pkgconfig/%{origname}.pc

%files %{python_files}
%license LICENSE
%doc python/README.md
%{python_sitearch}/%{origname}
%{python_sitearch}/python_%{origname}-*.egg-info

%ifpython2
%{python_sitearch}/_%{origlibname}.so
%else
%{python_sitearch}/_%{origlibname}.abi3.so
%endif

%changelog
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 3.2.16:
  * * Fix and modernize the Python packaging
* Sun Aug 13 2023 cunix@mail.de
- remove python future build dependency
* Wed Aug  9 2023 ecsos <ecsos@opensuse.org>
- Update to 3.2.15
  * Improvements to Python packaging
  - No longer depend on future since Python 2 is no longer supported.
  - Improve compatibility with tox 4.
  - Add support for making standalone sdist.
  * Improvements to Nix flake (Thanks to Jon Ringer)
  - Improve structure.
  - Enable Darwin builds.
  * TypeScript type fix
* Sun Jan 15 2023 Dirk Müller <dmueller@suse.com>
- update to 3.2.14:
  * TypeScript type improvements.
  * Improvements to Python packaging
  * Documentation improvements.
* Mon Oct 31 2022 cunix@mail.de
- build: removed "python_module" definition in spec file
* Sat Oct 29 2022 ecsos <ecsos@opensuse.org>
- Update to 3.2.13
  - Fix compilation with newer versions of emscripten.
  - The npm package is compiled with emscripten 3.1.17 to fix
    compatibility with node 18.
  - Add py.typed to Python wheels.
  - Some documentation fixes and updates.
  - Improve the pkgconfig file.
  The changes in this release do not affect the iOS or Android
  bindings, and should not affect the C library in most installs.
* Sun Jul 31 2022 cunix@mail.de
- Update to 3.2.12
  * Expose "olm_sas_calculate_mac_fixed_base64" in python bindings
  * Fix Python type hints
* Sun Jan 30 2022 ecsos <ecsos@opensuse.org>
- Update to 3.2.10
  - This release includes no change since 3.2.9, but is created to
    be able to publish again the Android library on MavenCentral.
- Changes from 3.2.9
  - Switch C++ tests to use doctest.
  - Switch JavaScript tests to use jasmine instead of deprecated
    jasmine-node.
  - Add session describe function to Python binding.
- Rebase cmake-enable-testing-builddir.patch.
- Skip Python2.
- Run spec-cleaner.
* Mon Dec 13 2021 cunix@mail.de
- Update to 3.2.8
  * Improve handling of olm_session_describe when the buffer is too small.
* Mon Dec 13 2021 ecsos <ecsos@opensuse.org>
- Update to 3.2.7
  * Fix installation with the Makefile.
  * Fix exporting again, so we only export olm symbols.
  * Fix WASM build.  Thanks to Benjamin Kampmann.
  * Add more functions for fallback keys.
* Mon Sep 20 2021 ecsos <ecsos@opensuse.org>
- Update to 3.2.6
  * Fix building on various platforms when using CMake.
    Building from the Makefile still assumes that it is using gcc.
- Changes from 3.2.5
  * Add functions for getting error codes rather than error strings.
  * Only export olm symbols.
  * Improve error handling in unpickle functions.
  * Add support for fallback keys to the Objective-C and Android bindings.
* Thu Jun  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.2.4
  * Add some checks for invalid input and ensure all fields are
    initialized.
  * Include LibreJS license tags.
- Add cmake-enable-testing-builddir.patch
- Enable testing
* Sat Apr 17 2021 cunix@mail.de
- Build and ship Python bindings.
* Fri Apr 16 2021 Wang Jun <jgwang@suse.com>
- Update to 3.2.2
  * Fixes in the TypeScript definition file.
  * CMake build fixes.  Thanks to Gorgurov Alexey.
  * Change the JavaScript package name to ``@matrix-org/olm``.  Note that
    this means that packages will need to change their ``require`` or
    ``import`` statements to use this new name.
  * Include file checksums in the JavaScript package.
  * Fix length calculation in fallback key json.  Thanks to Tobias Furuholm.
  * Add a new function to calculate the correct base64 encoding for SAS.
    (Currently only available in the C API.)
  * Add the ability to specify a pickle key in the Objective-C binding.
  * Add pkg-config file on Unix-like systems.
* Sun Nov 22 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.2.1
  * Add support for fallback keys (MSC2732).
  * Allow some arguments in the JavaScript bindings to be either
    Uint8Array or strings.
  * Fixes to the TypeScript definition file.
  * Improvements to the JavaScript group demo.
  * Ensure that the other party's public key has been set in SAS module.
  * Fix building with newer versions of emscripten, and simplify makefile.
  * Reduce pollution of the global namespace in the Javascript binding.
  * Fixes in the TypeScript definition file.
* Fri Jun 12 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.1.5
  * Build improvements:
  - Fix CMake handling when installing in a non-standard location.
  - Add support in the Makefile for creating a WASM-ready archive.
  - Improve support for LLVM is Makefile.
  * Add a TypeScript definition file.
  * Some documentation and example fixes.
  * Add list of bindings to the README.
* Wed Jan 29 2020 ecsos@opensuse.org
- Update to 3.1.4
  - Build improvements:
  - Install headers in the system-configured include directory with CMake.
  - Overwrite symbolic links when installing with make.
  - Improve compatibility with more emscripten versions.
  - Don't use hypothesis in Python unit tests.
  - Some documentation improvements.
- Run spec-cleaner.
* Sat Aug 10 2019 ecsos@opensuse.org
- Add missing cmake files.
* Mon Jul  8 2019 ecsos@opensuse.org
- Update to 3.1.3
  - This release fixes unicode issues in the Python bindings,
    and adds some clarifications to the documentation.
  - Since this release does not have any changes that affect
    the JavaScript bindings, there is no new NPM package.
- Changes from 3.1.2
  - This release updates the Android bindings to use a newer
    Android SDK version.
- Changes from 3.1.1
  - Include the SAS files and tests in the CMake files.
  - Address some build issues on Windows.
- Changes from 3.1.0
  - Add functions to support Short Authentication String key
    verification.  The new functions are in the sas.h header file.
    The Android, iOS, JavaScript and Python bindings also include
    corresponding functions.
  - Add functions to perform public key signing.  These are meant
    for use with cross-signing.  The new functions are
    olm_pk_signing_size, olm_pk_signing, olm_pk_signing_last_error,
    olm_clear_pk_signing, olm_pk_signing_key_from_seed,
    olm_pk_signing_seed_length, olm_pk_signing_public_key_length,
    olm_pk_signature_length, and olm_pk_sign.
    Signatures generated by olm_pk_sign can be verified using
    olm_ed25519_verify.  The Android, iOS, JavaScript and Python
    bindings also include corresponding functions.
  - Fix compilation under some compilers.
  - JavaScript wrapper:
  - Improved compatibility with newer versions of Emscripten,
    and dropped support
  - for some older versions of Emscripten.
  - Python wrapper:
  - Build fixes.
  - Add bindings for the public key encryption/decryption
    functions from olm 2.3.0.
- Changes from 3.0.0
  - Support for building using cmake. Thanks to Konstantinos
    Sideris.
  - Add more functions for managing private keys in the public
    key decryption functionality. These are meant for use with
    server-side encrypted key backups.  The new functions are
    olm_pk_private_key_length, olm_pk_key_from_private, and
    olm_pk_get_private_key.
  - olm_pk_generate_key and olm_pk_generate_key_random_length are
    deprecated: to generate a random key, use
    olm_pk_key_from_private with random bytes as the private key.
  - Python wrapper:
  - BREAKING CHANGE: This release introduces a new API for the
    Python wrapper, thanks to Damir Jelić.  The new API should
    be much easier to use for Python developers.  However, this
    means that existing code will need to be rewritten to use
    the new API.
  - JavaScript wrapper:
  - BREAKING CHANGE: Olm now uses WebAssembly which means it
    needs to load the wasm file asynchronously, and therefore
    needs to be started up asynchronously. The imported module
    now has an init() method which returns a promise.
    The library cannot be used until this promise resolves.
    It will reject if the library fails to start.
  - Using olm/olm.js will use the WebAssembly version of the
    library.  For environments that do not support WebAssembly,
    use olm/olm_legacy.js.
  - Objective-C wrapper:
  - Add support for the public key encryption/decryption functionality.
- Update source url.
- Run spec-cleaner.
* Fri Jul  6 2018 cunix@bitmessage.ch
- Ship License in libolm2 package
- spec reshuffel
- Update to 2.3.0
  * Avoid C99 inside C++ code
  * Support building as a static library
  * Add methods for public key encryption and decryption
* Sat Jun 30 2018 cunix@bitmessage.ch
- spec cleanup to fix build warnings
* Wed Jun 27 2018 windowskaput@gmail.com
- change spec and add devel pakage
* Sun Apr 15 2018 cunix@bitmessage.ch
- Initial Package with snapshot version 2.2.2
